<?php

namespace IQBall\Core\Model;

use IQBall\Core\Data\Color;
use IQBall\Core\Data\Team;
use IQBall\Core\Data\TeamInfo;
use IQBall\Core\Gateway\AccountGateway;
use IQBall\Core\Gateway\MemberGateway;
use IQBall\Core\Gateway\TeamGateway;

class TeamModel {
    private AccountGateway $users;
    private TeamGateway $teams;
    private MemberGateway $members;

    /**
     * @param TeamGateway $gateway
     * @param MemberGateway $members
     * @param AccountGateway $users
     */
    public function __construct(TeamGateway $gateway, MemberGateway $members, AccountGateway $users) {
        $this->teams = $gateway;
        $this->members = $members;
        $this->users = $users;
    }

    /**
     * @param string $name
     * @param string $picture
     * @param string $mainColor
     * @param string $secondColor
     * @return int
     */
    public function createTeam(string $name, string $picture, string $mainColor, string $secondColor): int {
        return $this->teams->insert($name, $picture, $mainColor, $secondColor);
    }

    /**
     * adds a member to a team
     * @param string $mail
     * @param int $teamId
     * @param string $role
     * @return int
     */
    public function addMember(string $mail, int $teamId, string $role): int {
        $user = $this->users->getAccountFromMail($mail);
        if($user == null){
            return -1;
        }
        if(!$this->members->isMemberOfTeam($teamId,$user->getUser()->getId())){
            $this->members->insert($teamId, $user->getUser()->getId(), $role);
            return 1;
        }
        return -2;
    }

    /**
     * @param string $name
     * @param int $id
     * @return TeamInfo[]
     */
    public function listByName(string $name,int $id): array {
        return $this->teams->listByName($name,$id);
    }

    /**
     * @param int $idTeam
     * @param int $idCurrentUser
     * @return ?Team
     */
    public function getTeam(int $idTeam, int $idCurrentUser): ?Team {
        if(!$this->members->isMemberOfTeam($idTeam,$idCurrentUser)){
            return null;
        }
        $teamInfo = $this->teams->getTeamById($idTeam);
        $members = $this->members->getMembersOfTeam($idTeam);
        return new Team($teamInfo, $members);
    }

    /**
     * delete a member from given team identifier
     * @param string $mail
     * @param int $teamId
     * @return int
     */
    public function deleteMember(int $idMember, int $teamId): int {
        $this->members->remove($teamId, $idMember);
        if(empty($this->members->getMembersOfTeam($teamId))){
            $this->teams->deleteTeam($teamId);
            return -1;
        }
        return $teamId;
    }

    public function deleteTeam(string $email, int $idTeam): int{
        if($this->members->isCoach($email,$idTeam)){
            $this->teams->deleteTeam($idTeam);
            return 0;
        }
        return -1;
    }

   public function isCoach(int $idTeam, string $email): bool{
        return $this->members->isCoach($email,$idTeam);
   }
}
